xskillscore: Metrics for verifying forecasts
============================================

.. image:: https://github.com/xarray-contrib/xskillscore/actions/workflows/xskillscore_testing.yml/badge.svg
   :target: https://github.com/xarray-contrib/xskillscore/actions/workflows/xskillscore_testing.yml

.. image:: https://github.com/xarray-contrib/xskillscore/actions/workflows/upstream-dev-ci.yml/badge.svg
   :target: https://github.com/xarray-contrib/xskillscore/actions/workflows/upstream-dev-ci.yml

.. image:: https://img.shields.io/pypi/v/xskillscore.svg
   :target: https://pypi.python.org/pypi/xskillscore/

.. image:: https://anaconda.org/conda-forge/xskillscore/badges/version.svg
   :target: https://anaconda.org/conda-forge/xskillscore/

.. image:: https://codecov.io/gh/xarray-contrib/xskillscore/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/xarray-contrib/xskillscore

.. image:: https://img.shields.io/conda/dn/conda-forge/xskillscore.svg
   :target: https://anaconda.org/conda-forge/xskillscore

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/raybellwaves/xskillscore-tutorial/master?urlpath=lab

Installation
============

You can install the latest release of ``xskillscore`` using ``pip`` or ``conda``:

.. code-block:: bash

    pip install xskillscore

.. code-block:: bash

    conda install -c conda-forge xskillscore

You can also install the bleeding edge (pre-release versions) by running:

.. code-block:: bash

    pip install git+https://github.com/xarray-contrib/xskillscore@main --upgrade

**Getting Started**

* :doc:`quick-start`

.. toctree::
    :maxdepth: 1
    :hidden:
    :caption: Getting Started

    quick-start.ipynb
    geophysical-data.ipynb
    tabular-data.ipynb

**Help & Reference**

* :doc:`api`
* :doc:`contributing`
* :doc:`changelog`
* :doc:`release_procedure`
* :doc:`related-projects`
* :doc:`contributors`

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Help & Reference

   api
   contributing
   changelog
   release_procedure
   related-projects
   contributors
